@@ -1,20 +1,17 @@
     template <typename Type>
-    concept bool Comparable()                           // function concept
-    {
-        return
-            requires(Type lhs, Type rhs)
-            {
-                { operator<(lhs, rhs) } -> bool;        // multiple
-                lhs + rhs;                              // constraints
-                typename Type::value_type;
-            };
-    }
-
-    template <typename Type>
-    concept bool Comparable2  =                          // variable concept
+    concept Comparable =                           // function concept
         requires(Type lhs, Type rhs)
         {
-            { operator<(lhs, rhs) } -> bool;
+//            { operator<(lhs, rhs) } -> bool;        // multiple
+            lhs + rhs;                              // constraints
+            typename Type::value_type;
+        };
+
+    template <typename Type>
+    concept Comparable2 =                          // variable concept
+        requires(Type lhs, Type rhs)
+        {
+//            { operator<(lhs, rhs) } -> bool;
             lhs + rhs;
             typename Type::value_type;
         };
