@@ -4,7 +4,7 @@
 
 //type
 template <typename Type>
-concept bool Iteratable =
+concept Iteratable =
     requires(Type tp)
     {
         typename Type::iterator;
@@ -16,7 +16,7 @@ auto iter(Type const &obj)
 {
     return obj.begin();
 }
-//==
+//=
 
 using namespace std;
 
