@@ -123,7 +123,7 @@ class CirQue
         d_front(d_data),
         d_back(d_data)
     {
-        std::copy(arr, arr + Size, back_inserter(*this));
+        std::copy(arr, arr + Size, std::back_inserter(*this));
     }
 //=
 //DESTRUCTOR
@@ -164,10 +164,12 @@ class CirQue
     template<typename Data>
     void CirQue<Data>::swap(CirQue<Data> &other)
     {
-        char tmp[sizeof(CirQue<Data>)];
-        memcpy(tmp, &other, sizeof(CirQue<Data>));
-        memcpy(&other, this, sizeof(CirQue<Data>));
-        memcpy(this, tmp, sizeof(CirQue<Data>));
+        static size_t const size = sizeof(CirQue<Data>);
+
+        char tmp[size];
+        memcpy(tmp, &other, size);
+        memcpy(reinterpret_cast<char *>(&other), this, size);
+        memcpy(reinterpret_cast<char *>(this), tmp, size);
     }
 //=
 
