@@ -9,11 +9,11 @@
     class IFdNStreambuf: public std::streambuf
     {
         protected:
-            int         d_fd;
-            size_t      d_bufsize;
-            char*       d_buffer;
+            int         d_fd = -1;
+            size_t      d_bufsize = 0;
+            char*       d_buffer = 0;
         public:
-            IFdNStreambuf();
+            IFdNStreambuf() = default;
             IFdNStreambuf(int fd, size_t bufsize = 1);
             virtual ~IFdNStreambuf();
             void open(int fd, size_t bufsize = 1);
@@ -24,11 +24,6 @@
 //=
 
 //CONS
-    inline IFdNStreambuf::IFdNStreambuf()
-    :
-        d_bufsize(0),
-        d_buffer(0)
-    {}
     inline IFdNStreambuf::IFdNStreambuf(int fd, size_t bufsize)
     {
         open(fd, bufsize);
@@ -52,7 +47,8 @@
     void IFdNStreambuf::open(int fd, size_t bufsize)
     {
         d_fd = fd;
-        d_bufsize = bufsize;
+        d_bufsize =  bufsize == 0 ? 1 : bufsize;
+        delete[] d_buffer;
         d_buffer = new char[d_bufsize];
         setg(d_buffer, d_buffer + d_bufsize, d_buffer + d_bufsize);
     }
