@@ -21,15 +21,15 @@
         list<string> first;
         list<string> second;
 
-        first.push_back(string("alpha"));
-        first.push_back(string("bravo"));
-        first.push_back(string("golf"));
-        first.push_back(string("quebec"));
+        first.push_back("alpha"s);
+        first.push_back("bravo"s);
+        first.push_back("golf"s);
+        first.push_back("quebec"s);
 
-        second.push_back(string("oscar"));
-        second.push_back(string("mike"));
-        second.push_back(string("november"));
-        second.push_back(string("zulu"));
+        second.push_back("oscar"s);
+        second.push_back("mike"s);
+        second.push_back("november"s);
+        second.push_back("zulu"s);
 
         first.merge(second);
         showlist(first);
