@@ -3,6 +3,7 @@
     #include <string>
     #include <cstring>
     #include <iterator>
+    #include <vector>
     using namespace std;
 
     bool caseless(string const &left, string const &right)
@@ -27,9 +28,17 @@
             set_union(set1, set1 + 7, set3, set3 + 3, result, caseless),
             ostream_iterator<string>(cout, " "));
         cout << '\n';
+
+        std::vector<int> v1 = {1, 2, 3,        4, 5, 5, 5};
+        std::vector<int> v2 = {      3, 3, 3,  4, 5,       6, 7};
+
+        set_union(v1.begin(), v1.end(), v2.begin(), v2.end(),
+                   ostream_iterator<int>(cout, " "));
+        cout << '\n';
     }
     /*
         Displays:
             kilo lima mike november oscar papa quebec romeo
             kilo lima mike november oscar papa quebec ROMEO
+            1 2 3 3 3 4 5 5 5 6 7
     */
