@@ -8,7 +8,7 @@ using namespace std;
 
 string *nStrings(size_t size, char const *fname)
 {
-    static ifstream in;
+    static thread_local ifstream in;
 
     struct Xstr: public string
     {
@@ -16,13 +16,13 @@ string *nStrings(size_t size, char const *fname)
         :
             string(nextLine())
         {}
-        static char const *nextLine()
+        static string nextLine()
         {
-            static string line;
+            string line;
 
             getline(in, line);
-            return line.c_str();
-        }
+            return line;        // copy elision turns this
+        }                       // into Xstr's base class string
     };
     in.open(fname);
     string *sp = new Xstr[size];
@@ -34,5 +34,5 @@ string *nStrings(size_t size, char const *fname)
 int main()
 {
     string *sp = nStrings(10, "nstrings.cc");
-    copy(sp, sp + 10, ostream_iterator<string>(cout, "\n"));
+    copy(sp, sp + 10, ostream_iterator<string>{ cout, "\n" });
 }
