@@ -14,8 +14,9 @@
             {
                 char buffer[sizeof(Reference)];
                 memcpy(buffer, this, sizeof(Reference));
-                memcpy(this, &other,  sizeof(Reference));
-                memcpy(&other, buffer, sizeof(Reference));
+                memcpy(static_cast<void *>(this), &other, sizeof(Reference));
+                memcpy(static_cast<void *>(&other), buffer,
+                                                    sizeof(Reference));
             }
             std::ostream &out()
             {
